@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -25,16 +25,17 @@ from calculate.lib.utils.portage import isPkgInstalled
 from calculate.install.install import InstallError
 from calculate.install.variables.autopartition import AutopartitionError
 
-setLocalTranslate('cl_install3',sys.modules[__name__])
+setLocalTranslate('cl_install3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+
 class ClSetupVideoAction(Action):
     """
     Действие для настройки параметров видео
     """
     # ошибки, которые отображаются без подробностей
-    native_error = (FilesError,MigrationError, TemplatesError,
-                  InstallError, AutopartitionError, DistributiveError)
+    native_error = (FilesError, MigrationError, TemplatesError,
+                    InstallError, AutopartitionError, DistributiveError)
 
     templateTaskMessage = __("Video settings are being configured")
     successMessage = __("Video settings configured!")
@@ -43,50 +44,51 @@ class ClSetupVideoAction(Action):
 
     addon_tasks = [
         # проверить и настроить параметры для nvidia драйвера
-        {'name':'check_video',
-        'message':__("Checking the video driver"),
-        'method':'Install.checkVideoDriver()',
-        'condition': lambda:isPkgInstalled('xorg-server')
-        },
-        {'name':'setup_opengl',
-        'message':__("Configuring OpenGL"),
-        'method':'Install.setupOpenGL()',
-        'condition': lambda:isPkgInstalled('xorg-server')
-        },
-        {'name':'setupvideo',
+        {'name': 'check_video',
+         'message': __("Checking the video driver"),
+         'method': 'Install.checkVideoDriver()',
+         'condition': lambda: isPkgInstalled('xorg-server')
+         },
+        {'name': 'setup_opengl',
+         'message': __("Configuring OpenGL"),
+         'method': 'Install.setupOpenGL()',
+         'condition': lambda: isPkgInstalled('xorg-server')
+         },
+        {'name': 'setupvideo',
          'condition': lambda Get: Get('cl_setup') == 'video'
-        },
-        {'name':'setupvideo:reboot',
-         'warning':__("To apply the changes, reboot the system"),
-         'condition': lambda Get:((Get('os_x11_video_drv') !=
-                Get('os_install_x11_video_drv') and
-                (Get('os_x11_video_drv') in Get('os_x11_kms_video_drv')
-                or Get('os_install_x11_video_drv')
-                    in Get('os_x11_kms_video_drv')))
-                    and Get('os_install_root_type') != 'livecd')
-        },
-        {'name':'setupvideo:restart',
-         'warning':__("To apply the changes, restart the X server"),
-         'condition': lambda Get:((Get('os_x11_video_drv') !=
-                Get('os_install_x11_video_drv') and
-                (not Get('os_x11_video_drv') in
-                     Get('os_x11_kms_video_drv') and
-                 not Get('os_install_x11_video_drv')
-                    in Get('os_x11_kms_video_drv')))
-                and Get('os_install_root_type') != 'livecd')
-        }
-        ]
+         },
+        {'name': 'setupvideo:reboot',
+         'warning': __("To apply the changes, reboot the system"),
+         'condition': lambda Get: ((Get('os_x11_video_drv') !=
+                                    Get('os_install_x11_video_drv') and
+                                    (Get('os_x11_video_drv') in Get(
+                                        'os_x11_kms_video_drv')
+                                     or Get('os_install_x11_video_drv')
+                                     in Get('os_x11_kms_video_drv')))
+                                   and Get('os_install_root_type') != 'livecd')
+         },
+        {'name': 'setupvideo:restart',
+         'warning': __("To apply the changes, restart the X server"),
+         'condition': lambda Get: ((Get('os_x11_video_drv') !=
+                                    Get('os_install_x11_video_drv') and
+                                    (not Get('os_x11_video_drv') in
+                                         Get('os_x11_kms_video_drv') and
+                                     not Get('os_install_x11_video_drv')
+                                         in Get('os_x11_kms_video_drv')))
+                                   and Get('os_install_root_type') != 'livecd')
+         }
+    ]
 
     def __init__(self):
         # список задач для действия
         self.tasks = [
-         {'name':'apply_templates',
-          'message':self.templateTaskMessage,
-          # наложить шаблоны на текущий дистрибутив, включая clt шаблоны
-          # без использования фильтров по clt шаблонам
-          'method': 'Install.applyTemplates(cl_source,cl_template_clt_set,'
-                    'cl_merge_set,None)',
-          }]
+            {'name': 'apply_templates',
+             'message': self.templateTaskMessage,
+             # наложить шаблоны на текущий дистрибутив, включая clt шаблоны
+             # без использования фильтров по clt шаблонам
+             'method': 'Install.applyTemplates(cl_source,cl_template_clt_set,'
+                       'cl_merge_set,None)',
+             }]
         # выполнить дополнительные задачи
         self.tasks.extend(self.addon_tasks)
         Action.__init__(self)
@@ -100,6 +102,7 @@ class ClSetupSystemAction(ClSetupVideoAction):
     successMessage = __("System configured!")
     failedMessage = __("Failed to configure the system!")
 
+
 class ClSetupAudioAction(ClSetupSystemAction):
     """
     Действие для настройки аудио параметров
@@ -109,6 +112,7 @@ class ClSetupAudioAction(ClSetupSystemAction):
     successMessage = __("Audio settings configured!")
     failedMessage = __("Failed to configure the audio parameters!")
 
+
 class ClSetupLocaleAction(ClSetupSystemAction):
     """
     Действие для настройки языковых параметров
@@ -119,6 +123,7 @@ class ClSetupLocaleAction(ClSetupSystemAction):
     successMessage = __("System configured!")
     failedMessage = __("Failed to configure the system!")
 
+
 class ClSetupNetworkAction(ClSetupSystemAction):
     """
     Действие для настройки аудио параметров
@@ -128,6 +133,7 @@ class ClSetupNetworkAction(ClSetupSystemAction):
     successMessage = __("Network settings configured!")
     failedMessage = __("Failed to configure the network settings!")
 
+
 class ClSetupSessionAction(ClSetupSystemAction):
     """
     Действие для настройки пользовательских параметров
@@ -137,6 +143,7 @@ class ClSetupSessionAction(ClSetupSystemAction):
     successMessage = __("Session settings configured!")
     failedMessage = __("Failed to configure the session settings!")
 
+
 class ClSetupBootAction(ClSetupSystemAction):
     """
     Действие для настройки параметров загрузки
@@ -147,25 +154,25 @@ class ClSetupBootAction(ClSetupSystemAction):
 
     addon_tasks = [
         # установить загрузчик
-        {'name':'prepare_bootloader',
-         'message':_("Installing the bootloader"),
-         'method':'Install.prepareBoot(cl_image)',
-         'condition':(lambda Get:(Get('os_install_mbr') or 
-            Get('os_install_uefi_set') == 'on') and
-            Get('os_root_type') != 'livecd' and 
-            Get('os_install_scratch') == 'off')
-        },
-        {'name':'no_scratch',
-         'warning':_("The builder mode is no longer supported"),
-         'condition':lambda Get:Get('os_install_scratch') == 'on'
-        },
+        {'name': 'prepare_bootloader',
+         'message': _("Installing the bootloader"),
+         'method': 'Install.prepareBoot(cl_image)',
+         'condition': (lambda Get: (Get('os_install_mbr') or
+                                    Get('os_install_uefi_set') == 'on') and
+                                   Get('os_root_type') != 'livecd' and
+                                   Get('os_install_scratch') == 'off')
+         },
+        {'name': 'no_scratch',
+         'warning': _("The builder mode is no longer supported"),
+         'condition': lambda Get: Get('os_install_scratch') == 'on'
+         },
         # изменить IO планировщик
-        {'name':'change_ioscheduler',
-         'message':_("Changing the I/O scheduler"),
-         'method':'Install.changeScheduler(os_install_kernel_scheduler)',
-         'condition':(lambda dv:dv.Get('os_root_type') != 'livecd' and 
-                               dv.Select('os_disk_parent',
-                               where='os_disk_mount',
-                               eq='/',limit=1))
-        },
-        ]
+        {'name': 'change_ioscheduler',
+         'message': _("Changing the I/O scheduler"),
+         'method': 'Install.changeScheduler(os_install_kernel_scheduler)',
+         'condition': (lambda dv: dv.Get('os_root_type') != 'livecd' and
+                                  dv.Select('os_disk_parent',
+                                            where='os_disk_mount',
+                                            eq='/', limit=1))
+         },
+    ]
